@@ -1,5 +1,7 @@
 #define QT_FEATURE_clock_gettime -1
 
+#define QT_FEATURE_close_range -1
+
 #define QT_FEATURE_doubleconversion 1
 
 #define QT_FEATURE_system_doubleconversion -1
@@ -38,6 +40,10 @@
 
 #define QT_FEATURE_poll_select -1
 
+#define QT_FEATURE_posix_sem 1
+
+#define QT_FEATURE_posix_shm -1
+
 #define QT_FEATURE_qqnx_pps -1
 
 #define QT_FEATURE_renameat2 -1
@@ -48,6 +54,10 @@
 
 #define QT_FEATURE_syslog -1
 
+#define QT_FEATURE_sysv_sem -1
+
+#define QT_FEATURE_sysv_shm -1
+
 #define QT_FEATURE_backtrace -1
 
 #define QT_FEATURE_cpp_winrt -1
@@ -68,3 +78,5 @@
 
 #define QT_FEATURE_poll_exit_on_error -1
 
+#define QT_FEATURE_openssl_hash -1
+
